==> hlint-2.1.14-47-x86_64.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.1.14
id: hlint-2.1.14-Apd29sMcYZVE4A3GrzdUaR
key: hlint-2.1.14-Apd29sMcYZVE4A3GrzdUaR
license: BSD-3-Clause
copyright: Neil Mitchell 2006-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
abi: eac8298f49b94b7e2baeac54b009b86d
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Timing CC Config.Compute Config.Haskell
                Config.Read Config.Type Config.Yaml HSE.All HSE.Match HSE.Reduce
                HSE.Scope HSE.Type HSE.Unify HSE.Util Hint.All Hint.Bracket
                Hint.Comment Hint.Duplicate Hint.Export Hint.Extensions Hint.Import
                Hint.Lambda Hint.List Hint.ListRec Hint.Match Hint.Monad
                Hint.Naming Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict
                Hint.Type Hint.Unsafe Hint.Util Test.All Test.Annotations
                Test.InputOutput Test.Proof Test.Translate Test.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/hlint-2.1.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/hlint-2.1.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.1.14-Apd29sMcYZVE4A3GrzdUaR
depends:
    aeson-1.4.4.0-7vLg8fT3jLZEAAmFwxYKHF
    ansi-terminal-0.9.1-4EGEPOXIA9UHNrgfDydiTP base-4.12.0.0
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 cpphs-1.20.8-ISt2D5MEyRI4QQUGFRtm5S
    data-default-0.7.1.1-GQk9Hqcpzml6dpaWfistUm directory-1.3.3.0
    extra-1.6.17-GS5yEZst6rmATRRpZlUQ12 filepath-1.4.2.1
    haskell-src-exts-1.21.0-KrNP1EKUN3L2qAEJHO5V0I
    haskell-src-exts-util-0.2.5-G25Ka5Qo6Cc46zcMiBQXhs
    hscolour-1.24.4-BEI90NJLSwF5tw227AM1ae process-1.6.5.0
    refact-0.3.0.2-1sV84vP3OHo15p4d2xAoYA text-1.2.3.1
    transformers-0.5.6.2 uniplate-1.6.12-LEDNla17gI8EfryIdoR2m9
    unordered-containers-0.2.10.0-1qvqZt81kSY49gkPLj6it0
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.1.0-JpzrK7nW2CYAcbLGaUKrvs
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hlint-2.1.14-52-x86_64.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.1.14
id: hlint-2.1.14-145p3Ic5Xn3Kq6TGIEG0VU
key: hlint-2.1.14-145p3Ic5Xn3Kq6TGIEG0VU
license: BSD-3-Clause
copyright: Neil Mitchell 2006-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
abi: 5918372a58b7ea443b12385d0345fbd5
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Timing CC Config.Compute Config.Haskell
                Config.Read Config.Type Config.Yaml HSE.All HSE.Match HSE.Reduce
                HSE.Scope HSE.Type HSE.Unify HSE.Util Hint.All Hint.Bracket
                Hint.Comment Hint.Duplicate Hint.Export Hint.Extensions Hint.Import
                Hint.Lambda Hint.List Hint.ListRec Hint.Match Hint.Monad
                Hint.Naming Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict
                Hint.Type Hint.Unsafe Hint.Util Test.All Test.Annotations
                Test.InputOutput Test.Proof Test.Translate Test.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/hlint-2.1.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/hlint-2.1.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.1.14-145p3Ic5Xn3Kq6TGIEG0VU
depends:
    aeson-1.4.4.0-HZF4dQ7ymfT471uy0aBwyJ
    ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X base-4.12.0.0
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 cpphs-1.20.8-ISt2D5MEyRI4QQUGFRtm5S
    data-default-0.7.1.1-1LPfbbioWzl7RPD13iVYcW directory-1.3.3.0
    extra-1.6.17-Gz9tBYjY7l0FvUCaVAXuat filepath-1.4.2.1
    haskell-src-exts-1.21.0-1f3RZCx0YCMHHsp4hwgt6k
    haskell-src-exts-util-0.2.5-CjDQWXDqOlDHvh7V9LC4sf
    hscolour-1.24.4-BEI90NJLSwF5tw227AM1ae process-1.6.5.0
    refact-0.3.0.2-1sV84vP3OHo15p4d2xAoYA text-1.2.3.1
    transformers-0.5.6.2 uniplate-1.6.12-GHnr6VZCTqId8dp50AILB
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.1.0-8jFA6LZR6hejvB1XYns97
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
